@@ -1,5 +1,5 @@
 '''
-files
+Files
 =====
 
 The following methods allow for interaction into the Tenable.io
@@ -9,14 +9,15 @@ Methods available on ``tio.files``:
 
 .. rst-class:: hide-signature
 .. autoclass:: FileAPI
-
-    .. automethod:: upload
+    :members:
 '''
+from typing import BinaryIO
 from .base import TIOEndpoint
 import uuid
 
 class FileAPI(TIOEndpoint):
-    def upload(self, fobj, encrypted=False):
+
+    def upload(self, fobj: BinaryIO, encrypted: bool = False):
         '''
         Uploads a file into Tenable.io.
 
@@ -45,4 +46,4 @@ class FileAPI(TIOEndpoint):
             kw['data'] = {'no_enc': int(encrypted)}
         kw['files'] = {'Filedata': fobj}
 
-        return self._api.post('file/upload', **kw).json()['fileuploaded']
\ No newline at end of file
+        return self._api.post('file/upload', **kw).json()['fileuploaded']
