@@ -1,5 +1,5 @@
 '''
-scanners
+Scanners
 ========
 
 The following methods allow for interaction into the Tenable.sc
@@ -10,14 +10,7 @@ Methods available on ``sc.scanners``:
 
 .. rst-class:: hide-signature
 .. autoclass:: ScannerAPI
-
-    .. automethod:: agent_scans
-    .. automethod:: create
-    .. automethod:: delete
-    .. automethod:: details
-    .. automethod:: edit
-    .. automethod:: list
-    .. automethod:: update_status
+    :members:
 '''
 from .base import SCEndpoint
 from tenable.utils import dict_merge
@@ -326,4 +319,4 @@ class ScannerAPI(SCEndpoint):
             >>> status = sc.scanners.update_status()
         '''
         return self._api.post('scanner/updateStatus',
-            json={}).json()['response']['status']
\ No newline at end of file
+            json={}).json()['response']['status']
